@@ -131,10 +131,15 @@ class Phemex(Exchange):
             "symbol": symbol,
             "untriggered": True,
         }
-        response = self._signed_request(self._path_config.get("cancel_orders").get("method"),
-                                        self._path_config.get("cancel_orders").get("path"),
-                                        params)
-        return response
+        conditional_response = self._signed_request(self._path_config.get("cancel_orders").get("method"),
+                                                    self._path_config.get("cancel_orders").get("path"),
+                                                    params)
+        params["untriggered"] = False
+        active_response = self._signed_request(self._path_config.get("cancel_orders").get("method"),
+                                               self._path_config.get("cancel_orders").get("path"),
+                                               params)
+
+        return {"conditional_orders": conditional_response, "active_orders": active_response}
 
     def get_data(self, symbol: str, interval: int, **kwargs):
         """
@@ -167,7 +172,24 @@ class Phemex(Exchange):
         if kwargs.get("is_dataframe", None):
             try:
                 columns = ["timestamp", "interval", "last_close", "open", "high", "low", "close", "volume", "turnover"]
-                return pd.DataFrame(response["data"]["rows"], columns=columns)
+                df = pd.DataFrame(response["data"]["rows"], columns=columns)
+                df["last_close"] = df["last_close"]/10000
+                df["open"] = df["open"] / 10000
+                df["high"] = df["high"] / 10000
+                df["low"] = df["low"] / 10000
+                df["close"] = df["close"] / 10000
+                return df
+            except Exception as e:
+                self._logger.error(e)
+        elif response.get("data", {}).get("rows"):
+            try:
+                for idx, data in enumerate(response.get("data", {}).get("rows")):
+                    response.get("data", {}).get("rows")[idx][2] = response.get("data", {}).get("rows")[idx][2] / 10000
+                    response.get("data", {}).get("rows")[idx][3] = response.get("data", {}).get("rows")[idx][3] / 10000
+                    response.get("data", {}).get("rows")[idx][4] = response.get("data", {}).get("rows")[idx][4] / 10000
+                    response.get("data", {}).get("rows")[idx][5] = response.get("data", {}).get("rows")[idx][5] / 10000
+                    response.get("data", {}).get("rows")[idx][6] = response.get("data", {}).get("rows")[idx][6] / 10000
+                return response
             except Exception as e:
                 self._logger.error(e)
         return response
@@ -201,7 +223,7 @@ class Phemex(Exchange):
         response = self._signed_request(self._path_config.get("get_orderbook").get("method"),
                                         self._path_config.get("get_orderbook").get("path"),
                                         params)
-        if is_dataframe and response.get("result"):
+        if is_dataframe:
             try:
                 columns = ['price', 'QTY']
                 bid = pd.DataFrame(response["result"]["book"]["bids"], columns=columns)
@@ -209,9 +231,18 @@ class Phemex(Exchange):
                 ask = pd.DataFrame(response["result"]["book"]["asks"], columns=columns)
                 ask["type"] = ["ask" for i in range(0, ask.shape[0])]
                 df = pd.concat([bid, ask], ignore_index=True)
+                df["price"] = df["price"] / 10000
                 return df
             except Exception as e:
                 logging.error(e)
+        elif response.get("result"):
+            try:
+                for idx, data in enumerate(response["result"]["book"]["bids"]):
+                    response["result"]["book"]["bids"][idx][0] = response["result"]["book"]["bids"][idx][0] / 10000
+                for idx, data in enumerate(response["result"]["book"]["asks"]):
+                    response["result"]["book"]["asks"][idx][0] = response["result"]["book"]["asks"][idx][0] / 10000
+            except Exception as e:
+                self._logger.error(e)
         return response
 
     def get_balance(self, currency="USD"):
@@ -240,7 +271,12 @@ class Phemex(Exchange):
                                         self._path_config.get("get_balance").get("path"),
                                         params)
         if response.get("data"):
-            return response.get("data", {}).get("account")
+            balance = response.get("data", {}).get("account")
+            if currency == 'USD':
+                balance["balance"] = balance.get("accountBalanceEv", 0) / 10000
+            elif currency.upper() == 'BTC':
+                balance["balance"] = balance.get("accountBalanceEv", 0) / 100000000
+            return balance
         return response
 
     def market_order(self, symbol: str, side: str, order_qty: float, **kwargs):
@@ -351,7 +387,7 @@ class Phemex(Exchange):
             "side": side,
             "ordType": "Limit",
             "orderQty": order_qty,
-            "priceEp": price,
+            "priceEp": price*10000,
             **kwargs
         }
         response = self._signed_request(self._path_config.get("limit_order").get("method"),
