@@ -6,7 +6,7 @@ def main():
                          secret="WcrWD3PceZ4KaeiMx1_z0ecQZJ7-Yq7CUbeNGaX7SrJjOGIyYzk0Yi03YzUyLTRlYmEtYWJiZi00Y2RjZjMxMzk0MDQ",
                          debug=True)
 
-    print(client.get_balance())
+    print(client.get_orderbook('BTCUSD'))
 
 
 if __name__ == "__main__":
